@@ -1,6 +1,6 @@
 package IRC::Message::Object;
 {
-  $IRC::Message::Object::VERSION = '0.070003';
+  $IRC::Message::Object::VERSION = '0.071000';
 }
 
 use strictures 1;
@@ -227,7 +227,12 @@ Shortcut for C<< IRC::Message::Object->new >>
 
 =head3 command
 
-The parsed command received. (No case-folding takes place.)
+The parsed command received.
+
+Note that if the C<command> is set at construction time, 
+no case-folding takes place.
+However, specifying a C<raw_line> at construction feeds 
+L<POE::Filter::IRCv3>, which will uppercase commands.
 
 predicate: C<has_command>
 
