@@ -1,6 +1,6 @@
 package IRC::Toolkit;
 {
-  $IRC::Toolkit::VERSION = '0.070003';
+  $IRC::Toolkit::VERSION = '0.071000';
 }
 
 use Carp;
@@ -45,6 +45,13 @@ IRC::Toolkit - Useful IRC objects and utilities
   ## Import all of the included Tookit:: modules:
   use IRC::Toolkit;
 
+  ## Import specific modules:
+  use IRC::Toolkit qw/
+    CTCP
+    Masks
+    Modes
+  /;
+
 =head1 DESCRIPTION
 
 A collection of useful IRC-related utilities. See their respective
@@ -68,6 +75,8 @@ L<IRC::Toolkit::Modes>; Mode-line parsing tools
 
 L<IRC::Toolkit::Parser>; Functional interface to L<POE::Filter::IRCv3>
 
+L<IRC::Toolkit::TS6>; Produce TS6 IDs
+
 =head1 SEE ALSO
 
 L<IRC::Utils>
